pub enum RouteDeviation {
NoDeviation,
Deviation {
kind: DeviationKind,
},
}Expand description
Status information that describes whether the user is proceeding according to the route or not.
Note that the name is intentionally a bit generic to allow for expansion of other states. For example, we could conceivably add a “wrong way” status in the future.
Variants
NoDeviation
The user is proceeding on course within the expected tolerances; everything is normal.
Deviation
The user has deviated from the expected route.
Check the DeviationKind to determine if the user is still on the route polyline
(off the current step but on a future step) or off the route entirely.
Fields
kind: DeviationKindImplementations
Sourceimpl RouteDeviation
impl RouteDeviation
Sourcepub fn is_deviated_from_current_step(&self) -> bool
pub fn is_deviated_from_current_step(&self) -> bool
Whether the user is no longer on the current step’s polyline.
This can happen either because the user has moved onto a future step without triggering advance, or because they have left the route entirely. In other words: any deviation from the current step.
Sourcepub fn is_completely_off_route(&self) -> bool
pub fn is_completely_off_route(&self) -> bool
Whether the user has deviated from the route entirely.
This is true when the user is not just deviated from the current step, but also from the route as a whole (they didn’t just take a shortcut).