pub struct UserLocation {
pub coordinates: GeographicCoordinate,
pub horizontal_accuracy: f64,
pub course_over_ground: Option<CourseOverGround>,
pub timestamp: SystemTime,
pub speed: Option<Speed>,
}Expand description
The location of the user that is navigating.
In addition to coordinates, this includes estimated accuracy and course information, which can influence navigation logic and UI.
NOTE: Heading is absent on purpose. Heading updates are not related to a change in the user’s location.
Fields
coordinates: GeographicCoordinatehorizontal_accuracy: f64The estimated accuracy of the coordinate (in meters)
course_over_ground: Option<CourseOverGround>timestamp: SystemTimespeed: Option<Speed>Trait Implementations
Sourceimpl Clone for UserLocation
impl Clone for UserLocation
Sourcefn clone(&self) -> UserLocation
fn clone(&self) -> UserLocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for UserLocation
impl<UT> ConvertError<UT> for UserLocation
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
impl Copy for UserLocation
Sourceimpl Debug for UserLocation
impl Debug for UserLocation
Sourceimpl<'de> Deserialize<'de> for UserLocation
impl<'de> Deserialize<'de> for UserLocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for UserLocation
impl<UT> FfiConverter<UT> for UserLocation
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<UserLocation> for Point
impl From<UserLocation> for Point
Sourcefn from(val: UserLocation) -> Point
fn from(val: UserLocation) -> Point
Converts to this type from the input type.
Sourceimpl<UT> Lift<UT> for UserLocation
impl<UT> Lift<UT> for UserLocation
Sourceimpl<UT> LiftRef<UT> for UserLocation
impl<UT> LiftRef<UT> for UserLocation
type LiftType = UserLocation
Sourceimpl<UT> LiftReturn<UT> for UserLocation
impl<UT> LiftReturn<UT> for UserLocation
Sourcetype ReturnType = <UserLocation as Lift<UT>>::FfiType
type ReturnType = <UserLocation as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for UserLocation
impl<UT> Lower<UT> for UserLocation
type FfiType = <UserLocation as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for UserLocation
impl<UT> LowerError<UT> for UserLocation
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for UserLocation
impl<UT> LowerReturn<UT> for UserLocation
Sourcetype ReturnType = <UserLocation as Lower<UT>>::FfiType
type ReturnType = <UserLocation as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl PartialEq for UserLocation
impl PartialEq for UserLocation
Sourceimpl PartialOrd for UserLocation
impl PartialOrd for UserLocation
Sourceimpl Serialize for UserLocation
impl Serialize for UserLocation
impl StructuralPartialEq for UserLocation
Sourceimpl<UT> TypeId<UT> for UserLocation
impl<UT> TypeId<UT> for UserLocation