GraphHopperHttpRequestGenerator

Struct GraphHopperHttpRequestGenerator 

pub struct GraphHopperHttpRequestGenerator { /* private fields */ }
A route request generator for GraphHopper backends operating over HTTP.

WaypointKind

The waypoint kind field of Waypoint is not currently supported in GraphHopper, as there is no multi-leg support. However, you can configure whether U-turns are allowed with the pass_through parameter. Refer to the GraphHopper documentation: https://docs.graphhopper.com/openapi/routing/getroute.

Waypoint properties

The Waypoint properties field is ignored by this route request generator.

Examples

use serde_json::{json, Map, Value};
use ferrostar::routing_adapters::graphhopper::{GraphHopperHttpRequestGenerator, GraphHopperVoiceUnits};
let options: Map<String, Value> = json!({
    "ch.disable": true,
    "custom_model": {
        "distance_influence": 15,
        "speed": [
            {
                "if": "road_class == MOTORWAY",
                "limit_to": "100"
            }
        ]
    }
}).as_object().unwrap().to_owned();
let request_generator = GraphHopperHttpRequestGenerator::new(
    "https://graphhopper.com/api/1/navigate/?key=YOUR-API-KEY",
    "car",
    "en",
    GraphHopperVoiceUnits::Metric,
    options
);

Implementations

Source

impl GraphHopperHttpRequestGenerator

pub fn new<U: Into<String>, P: Into<String>, L: Into<String>>( endpoint_url: U, profile: P, locale: L, voice_units: GraphHopperVoiceUnits, options: Map<String, JsonValue>, ) -> Self

Creates a new GraphHopper request generator given an endpoint URL, a profile name, and options to include in the request JSON.

Examples
use serde_json::{json, Map, Value};
use ferrostar::routing_adapters::graphhopper::{GraphHopperHttpRequestGenerator, GraphHopperVoiceUnits};
let options: Map<String, Value> = json!({
    "ch.disable": true,
    "custom_model": {
        "distance_influence": 15,
        "speed": [
            {
                "if": "road_class == MOTORWAY",
                "limit_to": "100"
            }
        ]
    }
}).as_object().unwrap().to_owned();
let request_generator = GraphHopperHttpRequestGenerator::new(
    "https://graphhopper.com/api/1/navigate/?key=YOUR-API-KEY",
    "car",
    "en",
    GraphHopperVoiceUnits::Metric,
    options
);
pub fn with_options_json<U: Into<String>, P: Into<String>, L: Into<String>>( endpoint_url: U, profile: P, locale: L, voice_units: GraphHopperVoiceUnits, options_json: Option<&str>, ) -> Result<Self, InstantiationError>

Creates a new GraphHopper request generator given an endpoint URL, a profile name, and options to include in the request JSON. Options in this constructor are a JSON fragment representing any options you want to add along with the request.

Examples
let options = r#"{
    "ch.disable": true,
    "custom_model": {
        "distance_influence": 15,
        "speed": [
            {
                "if": "road_class == MOTORWAY",
                "limit_to": "100"
            }
        ]
    }
}"#;

// Without options
let request_generator = GraphHopperHttpRequestGenerator::with_options_json(
    "https://graphhopper.com/api/1/navigate/?key=YOUR-API-KEY",
    "car",
    "en",
    GraphHopperVoiceUnits::Metric,
    None
);

// With options
let request_generator = GraphHopperHttpRequestGenerator::with_options_json(
    "https://graphhopper.com/api/1/navigate/?key=YOUR-API-KEY",
    "car",
    "en",
    GraphHopperVoiceUnits::Metric,
    Some(options)
);